import type { Dispatch, KeyboardEvent, SetStateAction } from 'react';
import { CornerDownLeft } from 'lucide-react';
import Image from 'next/image';

import { Button } from '~/components/ui/button';

const FirstStep = ({ setState }: { setState: Dispatch<SetStateAction<number>> }) => {
  const goToNextStep = () => setState(2);

  const handleKeyDown = (e: KeyboardEvent<HTMLDivElement>) => {
    if (e.key === 'Enter') {
      goToNextStep();
    }
  };

  return (
    <div
      className='grid h-full w-full grid-cols-1 lg:grid lg:grid-cols-2'
      onKeyDown={handleKeyDown}
      tabIndex={0}
    >
      <div className='flex items-center justify-center py-12'>
        <div className='mx-auto grid gap-6'>
          <div className='grid gap-2 text-center'>
            <h1 className='text-4xl font-bold'>Risparmia fino al 70% in meno sulle cure dentali</h1>
            <p className='text-balance text-lg text-muted-foreground'>
              Con la clinica Primo Dental in Albania puoi risparmiare fino al 70% sulle tue cure
              dentali senza rinunciare alla qualità dei materiali e alla professionalità dei
              dentisti
            </p>
          </div>
          <div className='mx-auto flex flex-row'>
            <Button size={'lg'} className='text-lg' onClick={goToNextStep}>
              Inzia Qui
            </Button>
            <Button size={'lg'} variant={'link'} className='text-lg' onClick={goToNextStep}>
              Premere Invio <CornerDownLeft className='size-8' />
            </Button>
          </div>
        </div>
      </div>
      <div className='hidden bg-muted lg:block'>
        <Image
          src='/Primo Dental.png'
          alt='Image'
          width='1920'
          height='1080'
          className='h-full w-full object-cover'
        />
      </div>
    </div>
  );
};

export default FirstStep;
